@@ -154,7 +154,7 @@ namespace pika::cuda::experimental {
                         detail::result_type_signature_helper_t<std::invoke_result_t<F, Ts...>>>;
 
             using completion_signatures =
-                pika::execution::experimental::make_completion_signatures<Sender,
+                pika::execution::experimental::transform_completion_signatures_of<Sender,
                     pika::execution::experimental::empty_env,
                     pika::execution::experimental::completion_signatures<
                         pika::execution::experimental::set_error_t(std::exception_ptr)>,
