@@ -30,6 +30,7 @@
 #include <chrono>
 #include <cmath>
 #include <cstddef>
+#include <cstdlib>
 #include <iostream>
 #include <random>
 #include <sstream>
@@ -61,8 +62,6 @@ struct sMatrixSize
 template <typename T>
 void matrixMultiply(sMatrixSize& matrix_size, std::size_t device, std::size_t iterations)
 {
-    using pika::execution::par;
-
     // Allocate host memory for matrices A and B
     unsigned int size_A = matrix_size.uiWA * matrix_size.uiHA;
     unsigned int size_B = matrix_size.uiWB * matrix_size.uiHB;
@@ -155,7 +154,8 @@ int pika_main(pika::program_options::variables_map& vm)
 
     matrixMultiply<float>(matrix_size, device, iterations);
 
-    return pika::finalize();
+    pika::finalize();
+    return EXIT_SUCCESS;
 }
 
 // -------------------------------------------------------------------------
