@@ -8,6 +8,7 @@
 #include <pika/command_line_handling/get_env_var_as.hpp>
 #include <pika/debugging/print.hpp>
 #include <pika/execution.hpp>
+#include <pika/execution_base/this_thread.hpp>
 #include <pika/init.hpp>
 #include <pika/mpi.hpp>
 #include <pika/program_options.hpp>
@@ -21,6 +22,7 @@
 //
 #include <array>
 #include <atomic>
+#include <cstddef>
 #include <cstdint>
 #include <cstdlib>
 #include <iomanip>
@@ -62,6 +64,7 @@ namespace mpix = pika::mpi::experimental;
 
 static bool output = false;
 static std::uint32_t mpi_poll_size = 16;
+static bool recv_before_send = false;
 std::atomic<std::uint32_t> counter;
 std::unique_ptr<pika::counting_semaphore<>> limiter;
 
@@ -261,69 +264,76 @@ struct message_receiver
         }
         else
         {
-            header hcopy = buf->header_;
+            auto f_send = [&] {
+                header hcopy = buf->header_;
 
-            // origin rank (step==0) receives one more than the other steps/ranks
-            if (buf->header_.step == 0 || (buf->header_.round < (num_rounds - 1)))
-            {
-                msg_info(rank, size, msg_type::recv, buf->header_, "recv_R");
-                // post a receive to handle it when it comes back on the next round
-                // we can reuse the same buffer for the forwarding send and for the receive,
-                // because the send _must_ complete before the receive
-                // even if there is only one rank in the ring
-                message_receiver reclambda(rank, orank, size, tag, num_rounds, message_size, buf);
+                // prepare new send buffer for forwarding message on
+                auto buf2 = get_msg_buffer(hcopy);
+                msg_info(rank, size, msg_type::send, buf2->header_, "send_R");
+                auto tx_snd2 = ex::just(buf2, message_size, MPI_UNSIGNED_CHAR,
+                                   next_rank(rank, size), tag, MPI_COMM_WORLD) |
+                    mpix::transform_mpi(MPI_Isend /*, mpix::stream_type::send_2*/) |
+                    ex::then([buf2 = buf2, rank = rank, size = size](/*int result*/) {
+                        counter--;
+                        msg_info(rank, size, msg_type::send, buf2->header_, "forwarded");
+                        release_msg_buffer(buf2);
+                    });
 
-                // the recursive lambda will handle it
-                auto rx_snd2 = ex::just(buf, message_size, MPI_UNSIGNED_CHAR, prev_rank(rank, size),
-                                   tag, MPI_COMM_WORLD) |
-                    mpix::transform_mpi(MPI_Irecv /*, mpix::stream_type::receive_2*/) |
-                    ex::then(std::move(reclambda));
-                // launch the receive for the msg on the next round
+                // launch the forwarding send for the current round
                 msr_deb<6>.debug(
-                    str<>("start_detached"), "rx_snd2", buf->header_.round, buf->header_.step);
-                ex::start_detached(std::move(rx_snd2));
+                    str<>("start_detached"), "tx_snd2", buf2->header_.round, buf2->header_.step);
+                ex::start_detached(std::move(tx_snd2));
+            };
+
+            auto f_recv = [&] {
+                // origin rank (step==0) receives one more than the other steps/ranks
+                if (buf->header_.step == 0 || (buf->header_.round < (num_rounds - 1)))
+                {
+                    msg_info(rank, size, msg_type::recv, buf->header_, "recv_R");
+                    // post a receive to handle it when it comes back on the next round
+                    // we can reuse the same buffer for the forwarding send and for the receive,
+                    // because the send _must_ complete before the receive
+                    // even if there is only one rank in the ring
+                    message_receiver reclambda(
+                        rank, orank, size, tag, num_rounds, message_size, buf);
+
+                    // the recursive lambda will handle it
+                    auto rx_snd2 = ex::just(buf, message_size, MPI_UNSIGNED_CHAR,
+                                       prev_rank(rank, size), tag, MPI_COMM_WORLD) |
+                        mpix::transform_mpi(MPI_Irecv /*, mpix::stream_type::receive_2*/) |
+                        ex::then(std::move(reclambda));
+                    // launch the receive for the msg on the next round
+                    msr_deb<6>.debug(
+                        str<>("start_detached"), "rx_snd2", buf->header_.round, buf->header_.step);
+                    ex::start_detached(std::move(rx_snd2));
+                }
+                else { release_msg_buffer(buf); }
+            };
+
+            if (recv_before_send)
+            {
+                f_recv();
+                f_send();
+            }
+            else
+            {
+                f_send();
+                f_recv();
             }
-            else { release_msg_buffer(buf); }
-
-            // prepare new send buffer for forwarding message on
-            auto buf2 = get_msg_buffer(hcopy);
-            msg_info(rank, size, msg_type::send, buf2->header_, "send_R");
-            auto tx_snd2 = ex::just(buf2, message_size, MPI_UNSIGNED_CHAR, next_rank(rank, size),
-                               tag, MPI_COMM_WORLD) |
-                mpix::transform_mpi(MPI_Isend /*, mpix::stream_type::send_2*/) |
-                ex::then([buf2 = buf2, rank = rank, size = size](/*int result*/) {
-                    counter--;
-                    msg_info(rank, size, msg_type::send, buf2->header_, "forwarded");
-                    release_msg_buffer(buf2);
-                });
-
-            // launch the forwarding send for the current round
-            msr_deb<6>.debug(
-                str<>("start_detached"), "tx_snd2", buf2->header_.round, buf2->header_.step);
-            ex::start_detached(std::move(tx_snd2));
         }
     }
 };
 
-// ------------------------------------------------------------
-int call_mpi_irecv(void* buf, int count, MPI_Datatype datatype, int source, int tag, MPI_Comm comm,
-    MPI_Request* request)
-{
-    int res = MPI_Irecv(buf, count, datatype, source, tag, comm, request);
-    msr_deb<6>.debug(str<>("MPI_Irecv"), dec<5>(count));
-    return res;
-}
-
 // ------------------------------------------------------------
 // this is called on a pika thread after the runtime starts up
 int pika_main(pika::program_options::variables_map& vm)
 {
-    // setup polling on default pool, enable exceptions and init mpi internals
+    // Do not initialize mpi (we do that ourselves), do install an error handler
     mpix::init(false, true);
+    // Setup mpi polling on default pool, enable exceptions and init mpi internals
     mpix::register_polling();
     //
     std::int32_t rank, size;
-    //
     MPI_Comm_size(MPI_COMM_WORLD, &size);
     MPI_Comm_rank(MPI_COMM_WORLD, &rank);
 
@@ -343,6 +353,7 @@ int pika_main(pika::program_options::variables_map& vm)
     const std::uint32_t iterations = vm["iterations"].as<std::uint32_t>();
     const std::uint32_t num_rounds = vm["rounds"].as<std::uint32_t>();
     output = vm.count("output") != 0;
+    recv_before_send = vm["recv-before-send"].as<bool>();
     //
     std::uint32_t in_flight = 65536;
     if (vm.count("in-flight-limit")) { in_flight = vm["in-flight-limit"].as<std::uint32_t>(); }
@@ -374,48 +385,65 @@ int pika_main(pika::program_options::variables_map& vm)
             msr_deb<3>.debug(str<>("acquire"), i);
             limiter->acquire();
 
-            // every rank starts a ring send,
-            // on first round - every rank receives a message from all other ranks
-            for (std::uint32_t orank = 0; orank < std::uint32_t(size); orank++)
-            {
-                // post a ring receive for each rank at this iteration
-                // the message is always received from the previous rank
-                // and has the tag associated with the originating rank
+            auto f_send = [&] {
+                // start the ring (first message) message for this iteration/rank
                 std::uint32_t tag =
-                    make_tag(std::uint32_t(orank), std::uint32_t(i), std::uint32_t(size));
-                auto rbuf = get_msg_buffer(header{0, tag, i, 0, 0, orank, message_size});
-                msg_info(rank, size, msg_type::recv, rbuf->header_, "recv");
+                    make_tag(std::uint32_t(rank), std::uint32_t(i), std::uint32_t(size));
+                auto sbuf =
+                    get_msg_buffer(header{0, tag, i, 0, 0, std::uint32_t(rank), message_size});
+                auto send_snd = ex::just(sbuf, message_size, MPI_UNSIGNED_CHAR,
+                                    next_rank(rank, size), tag, MPI_COMM_WORLD) |
+                    mpix::transform_mpi(MPI_Isend /*, mpix::stream_type::send_1*/) |
+                    ex::then([rank, size, sbuf](/*int res*/) {
+                        counter--;
+                        msg_info(rank, size, msg_type::send, sbuf->header_, "sent");
+                        release_msg_buffer(sbuf);
+                    });
+                msg_info(rank, size, msg_type::send, sbuf->header_, "send");
+                msr_deb<6>.debug(str<>("start_detached"), "send_snd", i);
+                ex::start_detached(std::move(send_snd));
+            };
 
-                // a handler for a receive that recursively posts receives and handles them
-                message_receiver reclambda(rank, orank, size, tag, num_rounds, message_size, rbuf);
-                // create chain of senders to make the mpi recv and handle it
-                auto rx_snd1 = ex::just(rbuf, message_size, MPI_UNSIGNED_CHAR,
-                                   prev_rank(rank, size), tag, MPI_COMM_WORLD) |
-                    mpix::transform_mpi(MPI_Irecv /*, mpix::stream_type::receive_1*/) |
-                    ex::then(std::move(reclambda));
-                msr_deb<6>.debug(str<>("start_detached"), "rx_snd1", i, orank);
-                ex::start_detached(std::move(rx_snd1));
+            auto f_recv = [&] {
+                // every rank starts a ring send,
+                // on first round - every rank receives a message from all other ranks
+                for (std::uint32_t orank = 0; orank < std::uint32_t(size); orank++)
+                {
+                    // post a ring receive for each rank at this iteration
+                    // the message is always received from the previous rank
+                    // and has the tag associated with the originating rank
+                    std::uint32_t tag =
+                        make_tag(std::uint32_t(orank), std::uint32_t(i), std::uint32_t(size));
+                    auto rbuf = get_msg_buffer(header{0, tag, i, 0, 0, orank, message_size});
+                    msg_info(rank, size, msg_type::recv, rbuf->header_, "recv");
+
+                    // a handler for a receive that recursively posts receives and handles them
+                    message_receiver reclambda(
+                        rank, orank, size, tag, num_rounds, message_size, rbuf);
+                    // create chain of senders to make the mpi recv and handle it
+                    auto rx_snd1 = ex::just(rbuf, message_size, MPI_UNSIGNED_CHAR,
+                                       prev_rank(rank, size), tag, MPI_COMM_WORLD) |
+                        mpix::transform_mpi(MPI_Irecv /*, mpix::stream_type::receive_1*/) |
+                        ex::then(std::move(reclambda));
+                    msr_deb<6>.debug(str<>("start_detached"), "rx_snd1", i, orank);
+                    ex::start_detached(std::move(rx_snd1));
+                }
+            };
+
+            if (recv_before_send)
+            {
+                f_recv();
+                f_send();
+            }
+            else
+            {
+                f_send();
+                f_recv();
             }
-
-            // start the ring (first message) message for this iteration/rank
-            std::uint32_t tag =
-                make_tag(std::uint32_t(rank), std::uint32_t(i), std::uint32_t(size));
-            auto sbuf = get_msg_buffer(header{0, tag, i, 0, 0, std::uint32_t(rank), message_size});
-            auto send_snd = ex::just(sbuf, message_size, MPI_UNSIGNED_CHAR, next_rank(rank, size),
-                                tag, MPI_COMM_WORLD) |
-                mpix::transform_mpi(MPI_Isend /*, mpix::stream_type::send_1*/) |
-                ex::then([rank, size, sbuf](/*int res*/) {
-                    counter--;
-                    msg_info(rank, size, msg_type::send, sbuf->header_, "sent");
-                    release_msg_buffer(sbuf);
-                });
-            msg_info(rank, size, msg_type::send, sbuf->header_, "send");
-            msr_deb<6>.debug(str<>("start_detached"), "send_snd", i);
-            ex::start_detached(std::move(send_snd));
         }
 
         // don't exit until all messages are drained
-        while (counter > 0) { pika::this_thread::yield(); }
+        pika::util::yield_while([&] { return counter > 0; });
         if (output)
         {
             // clang-format off
@@ -427,7 +455,7 @@ int pika_main(pika::program_options::variables_map& vm)
         }
 
         // the user queue should always be empty by now since our counter tracks it
-        PIKA_ASSERT(mpix::get_work_count() == 0);
+        PIKA_TEST_EQ(mpix::get_work_count(), static_cast<std::size_t>(0));
 
         double elapsed = t.elapsed();
 
@@ -458,6 +486,10 @@ void init_resource_partitioner_handler(
     auto pool_mode = mpix::pool_create_mode::pika_decides;
     if (vm["no-mpi-pool"].as<bool>()) { pool_mode = mpix::pool_create_mode::force_no_create; }
 
+    mpix::enable_optimizations(vm["mpi-optimizations"].as<bool>());
+    std::cout << "init_resource_partitioner_handler enable optimizations "
+              << vm["mpi-optimizations"].as<bool>() << std::endl;
+
     msr_deb<2>.debug(str<>("init RP"), "create_pool");
     mpix::create_pool("", pool_mode);
 }
@@ -468,14 +500,6 @@ void init_resource_partitioner_handler(
 // will execute pika_main on a pika thread
 int main(int argc, char* argv[])
 {
-    // Init MPI
-    int provided = MPI_THREAD_MULTIPLE;
-    MPI_Init_thread(&argc, &argv, MPI_THREAD_MULTIPLE, &provided);
-    if (provided != MPI_THREAD_MULTIPLE)
-    {
-        std::cout << "Provided MPI is not : MPI_THREAD_MULTIPLE " << provided << std::endl;
-    }
-
     // Configure application-specific options.
     options_description cmdline("usage: " PIKA_APPLICATION_STRING " [options]");
 
@@ -495,9 +519,6 @@ int main(int argc, char* argv[])
     cmdline.add_options()("no-mpi-pool", pika::program_options::bool_switch(),
         "Disable the MPI pool.");
 
-    // cmdline.add_options()("one-rank-consistent", pika::program_options::bool_switch(),
-    //     "Use an mpi pool even on one rank if the mode flags expect it");
-
     cmdline.add_options()("mpi-polling-size",
         pika::program_options::value<std::uint32_t>()->default_value(16),
         "The maximum number of mpi request completions to handle per poll.");
@@ -506,12 +527,18 @@ int main(int argc, char* argv[])
         pika::program_options::value<std::uint32_t>()->default_value(64),
         "Specify the buffer size to use for messages (min 16).");
 
+    cmdline.add_options()("recv-before-send", pika::program_options::bool_switch(),
+        "Submit MPI_Irecvs before MPI_Isends instead of other way around.");
+
     cmdline.add_options()("output",
         "Display messages during test");
 
     cmdline.add_options()("standalone",
         "Allow test to run with a single rank (debugging)");
 
+    cmdline.add_options()("mpi-optimizations", pika::program_options::bool_switch(),
+        "do not change pool, or thread level");
+
     cmdline.add_options()("csv", pika::program_options::bool_switch()->default_value(false),
                      "Enable CSV output of values");
 
@@ -519,6 +546,23 @@ int main(int argc, char* argv[])
                      "Info for postprocessing scripts appended to csv output (if enabled)");
     // clang-format on
 
+    // -----------------
+    // process command line options early so we can use them for mpi_init
+    namespace po = pika::program_options;
+    po::variables_map vm;
+    po::store(po::command_line_parser(argc, argv).options(cmdline).allow_unregistered().run(), vm);
+    po::notify(vm);
+
+    // -----------------
+    // Init MPI
+    int provided, preferred = mpix::get_preferred_thread_mode();
+    MPI_Init_thread(&argc, &argv, preferred, &provided);
+    if (provided != preferred)
+    {
+        msr_deb<0>.error(str<>("Caution"), "Provided MPI is not as requested");
+    }
+
+    // -----------------
     // Initialize and run pika.
     pika::init_params init_args;
     init_args.desc_cmdline = cmdline;
@@ -528,6 +572,7 @@ int main(int argc, char* argv[])
     auto result = pika::init(pika_main, argc, argv, init_args);
     PIKA_TEST_EQ(result, 0);
 
+    // -----------------
     // Finalize MPI
     MPI_Finalize();
     return result;
