@@ -45,7 +45,7 @@ namespace pika::ensure_started_detail {
     template <typename Receiver>
     struct error_visitor
     {
-        PIKA_NO_UNIQUE_ADDRESS std::decay_t<Receiver> receiver;
+        std::decay_t<Receiver>& receiver;
 
         template <typename Error>
         void operator()(Error&& error)
@@ -58,7 +58,7 @@ namespace pika::ensure_started_detail {
     template <typename Receiver>
     struct value_visitor
     {
-        PIKA_NO_UNIQUE_ADDRESS std::decay_t<Receiver> receiver;
+        std::decay_t<Receiver>& receiver;
 
         void operator()(std::monostate) { PIKA_UNREACHABLE; }
 
@@ -216,7 +216,7 @@ namespace pika::ensure_started_detail {
             template <typename Receiver>
             struct stopped_error_value_visitor
             {
-                PIKA_NO_UNIQUE_ADDRESS std::decay_t<Receiver> receiver;
+                std::decay_t<Receiver>& receiver;
 
                 template <typename T,
                     typename =
@@ -234,8 +234,7 @@ namespace pika::ensure_started_detail {
 
                 void operator()(error_type&& error)
                 {
-                    pika::detail::visit(
-                        error_visitor<Receiver>{PIKA_MOVE(receiver)}, PIKA_MOVE(error));
+                    pika::detail::visit(error_visitor<Receiver>{receiver}, PIKA_MOVE(error));
                 }
 
                 template <typename T,
@@ -244,8 +243,7 @@ namespace pika::ensure_started_detail {
                         std::is_same_v<std::decay_t<T>, value_type>>>
                 void operator()(T&& t)
                 {
-                    pika::detail::visit(
-                        value_visitor<Receiver>{PIKA_MOVE(receiver)}, PIKA_FORWARD(T, t));
+                    pika::detail::visit(value_visitor<Receiver>{receiver}, PIKA_FORWARD(T, t));
                 }
             };
 
@@ -303,10 +301,7 @@ namespace pika::ensure_started_detail {
             }
 
             template <typename Receiver>
-            void add_continuation(Receiver& receiver) = delete;
-
-            template <typename Receiver>
-            void add_continuation(Receiver&& receiver)
+            void add_continuation(Receiver& receiver)
             {
                 PIKA_ASSERT(!continuation.has_value());
 
@@ -319,8 +314,7 @@ namespace pika::ensure_started_detail {
                     // TODO: Should this preserve the scheduler? It does not
                     // if we call set_* inline.
                     pika::detail::visit(
-                        stopped_error_value_visitor<Receiver>{PIKA_FORWARD(Receiver, receiver)},
-                        PIKA_MOVE(v));
+                        stopped_error_value_visitor<Receiver>{receiver}, PIKA_MOVE(v));
                 }
                 else
                 {
@@ -336,8 +330,7 @@ namespace pika::ensure_started_detail {
                         // directly again.
                         l.unlock();
                         pika::detail::visit(
-                            stopped_error_value_visitor<Receiver>{PIKA_FORWARD(Receiver, receiver)},
-                            PIKA_MOVE(v));
+                            stopped_error_value_visitor<Receiver>{receiver}, PIKA_MOVE(v));
                     }
                     else
                     {
@@ -345,12 +338,10 @@ namespace pika::ensure_started_detail {
                         // continuation. This has to be done while holding
                         // the lock since predecessor signalling completion
                         // may otherwise not see the continuation.
-                        continuation.emplace(
-                            [this, receiver = PIKA_FORWARD(Receiver, receiver)]() mutable {
-                                pika::detail::visit(
-                                    stopped_error_value_visitor<Receiver>{PIKA_MOVE(receiver)},
-                                    PIKA_MOVE(v));
-                            });
+                        continuation.emplace([this, &receiver]() mutable {
+                            pika::detail::visit(
+                                stopped_error_value_visitor<Receiver>{receiver}, PIKA_MOVE(v));
+                        });
                     }
                 }
             }
@@ -425,7 +416,7 @@ namespace pika::ensure_started_detail {
             friend void tag_invoke(
                 pika::execution::experimental::start_t, operation_state& os) noexcept
             {
-                os.state->add_continuation(PIKA_MOVE(os.receiver));
+                os.state->add_continuation(os.receiver);
             }
         };
 
