@@ -14,21 +14,23 @@
 
 void is_sized_sentinel_for()
 {
-    PIKA_TEST_MSG((pika::traits::is_sized_sentinel_for<sentinel<int64_t>,
-                       iterator<std::int64_t>>::value == false),
+    PIKA_TEST_MSG(
+        (pika::traits::is_sized_sentinel_for<sentinel<int64_t>, iterator<std::int64_t>>::value ==
+            false),
         "Sentinel falsely marked as sized for particular iterator");
 
-    PIKA_TEST_MSG(
-        (pika::traits::is_sized_sentinel_for<std::vector<int>::iterator,
-             std::vector<int>::iterator>::value == true),
+    PIKA_TEST_MSG((pika::traits::is_sized_sentinel_for<std::vector<int>::iterator,
+                       std::vector<int>::iterator>::value == true),
         "Begin end iterator (vector) pair should be sized");
 
-    PIKA_TEST_MSG((pika::traits::is_sized_sentinel_for<std::string::iterator,
-                       std::string::iterator>::value == true),
+    PIKA_TEST_MSG(
+        (pika::traits::is_sized_sentinel_for<std::string::iterator, std::string::iterator>::value ==
+            true),
         "Begin end iterator (string) pair should be sized");
 
-    PIKA_TEST_MSG((pika::traits::is_sized_sentinel_for<std::int64_t,
-                       std::vector<int>::iterator>::value == false),
+    PIKA_TEST_MSG(
+        (pika::traits::is_sized_sentinel_for<std::int64_t, std::vector<int>::iterator>::value ==
+            false),
         "Integer is not a sized sentinel for a vector iterator");
 }
 
