@@ -10,6 +10,8 @@
 #include <pika/init.hpp>
 #include <pika/testing.hpp>
 
+#include <cstdlib>
+
 char const* argv[] = {"command_line_argument_test",
     // We need only one thread, this argument should be gone in pika_main
     "--pika:threads=1", "nx=1", "ny=1=5"};
@@ -20,7 +22,8 @@ int pika_main(int argc, char** argv_init)
     PIKA_TEST_EQ(0, std::strcmp(argv[0], argv_init[0]));
     for (int i = 1; i < argc; ++i) { PIKA_TEST_EQ(0, std::strcmp(argv[i + 1], argv_init[i])); }
 
-    return pika::finalize();
+    pika::finalize();
+    return EXIT_SUCCESS;
 }
 
 int main()
