@@ -93,7 +93,7 @@ int pika_main()
     // randomly create tasks that run on a random pool
     // attach continuations to them that run on different
     // random pools
-#if defined(PIKA_HAVE_VERIFY_LOCKS)
+#if defined(PIKA_HAVE_VERIFY_LOCKS) || defined(PIKA_HAVE_VALGRIND)
     constexpr int loops = 20;
 #else
     constexpr int loops = 500;
@@ -220,7 +220,7 @@ void init_resource_partitioner_handler(pika::resource::partitioner& rp,
     std::size_t threads_remaining = max_threads;
     std::size_t threads_in_pool = 0;
     // create pools randomly and add a random number of PUs to each pool
-    for (pika::resource::numa_domain const& d : rp.numa_domains())
+    for (pika::resource::socket const& d : rp.sockets())
     {
         for (pika::resource::core const& c : d.cores())
         {
