@@ -11,8 +11,8 @@
 #include <pika/affinity/affinity_data.hpp>
 #include <pika/assert.hpp>
 #include <pika/functional/function.hpp>
+#include <pika/logging.hpp>
 #include <pika/modules/errors.hpp>
-#include <pika/modules/logging.hpp>
 #include <pika/schedulers/deadlock_detection.hpp>
 #include <pika/schedulers/lockfree_queue_backends.hpp>
 #include <pika/schedulers/thread_queue.hpp>
@@ -272,15 +272,11 @@ namespace pika::threads::detail {
             PIKA_ASSERT(num_thread < queue_size);
             queues_[num_thread]->create_thread(data, id, ec);
 
-            LTM_(debug)
-                .format("local_queue_scheduler::create_thread: pool({}), scheduler({}), "
-                        "worker_thread({}), thread({})",
-                    *this->get_parent_pool(), *this, num_thread,
-                    id ? *id : threads::detail::invalid_thread_id)
-#ifdef PIKA_HAVE_THREAD_DESCRIPTION
-                .format(", description({})", data.description)
-#endif
-                ;
+            PIKA_LOG(debug,
+                "local_queue_scheduler::create_thread: pool({}), scheduler({}), "
+                "worker_thread({}), thread({}), description({})",
+                *this->get_parent_pool(), *this, num_thread,
+                id ? *id : threads::detail::invalid_thread_id, data.get_description());
         }
 
         /// Return the next thread to be executed, return false if none is
@@ -427,8 +423,9 @@ namespace pika::threads::detail {
 
             PIKA_ASSERT(num_thread < queues_.size());
 
-            LTM_(debug).format("local_queue_scheduler::schedule_thread: pool({}), scheduler({}), "
-                               "worker_thread({}), thread({}), description({})",
+            PIKA_LOG(debug,
+                "local_queue_scheduler::schedule_thread: pool({}), scheduler({}), "
+                "worker_thread({}), thread({}), description({})",
                 *this->get_parent_pool(), *this, num_thread,
                 get_thread_id_data(thrd)->get_thread_id(),
                 get_thread_id_data(thrd)->get_description());
@@ -736,7 +733,7 @@ namespace pika::threads::detail {
 
 #ifdef PIKA_HAVE_THREAD_DEADLOCK_DETECTION
             // no new work is available, are we deadlocked?
-            if (PIKA_UNLIKELY(get_deadlock_detection_enabled() && LPIKA_ENABLED(error)))
+            if (PIKA_UNLIKELY(get_deadlock_detection_enabled() && PIKA_LOG_ENABLED(err)))
             {
                 bool suspended_only = true;
 
@@ -750,16 +747,17 @@ namespace pika::threads::detail {
                 {
                     if (running)
                     {
-                        LTM_(warning).format("pool({}), scheduler({}), queue({}): no new work "
-                                             "available, are we deadlocked?",
+                        PIKA_LOG(warn,
+                            "pool({}), scheduler({}), queue({}): no new work "
+                            "available, are we deadlocked?",
                             *this->get_parent_pool(), *this, num_thread);
                     }
                     else
                     {
-                        LPIKA_CONSOLE_(pika::util::logging::level::warning)
-                            .format("  [TM] pool({}), scheduler({}), queue({}): no new work "
-                                    "available, are we deadlocked?\n",
-                                *this->get_parent_pool(), *this, num_thread);
+                        PIKA_LOG(warn,
+                            "  [TM] pool({}), scheduler({}), queue({}): no new work "
+                            "available, are we deadlocked?\n",
+                            *this->get_parent_pool(), *this, num_thread);
                     }
                 }
             }
