@@ -7,8 +7,8 @@
 
 #include <pika/assert.hpp>
 #include <pika/execution_base/this_thread.hpp>
+#include <pika/logging.hpp>
 #include <pika/modules/errors.hpp>
-#include <pika/modules/logging.hpp>
 #include <pika/modules/memory.hpp>
 #include <pika/synchronization/detail/condition_variable.hpp>
 #include <pika/synchronization/no_mutex.hpp>
@@ -31,7 +31,7 @@ namespace pika::detail {
     {
         if (!queue_.empty())
         {
-            LERR_(fatal).format("~condition_variable: queue is not empty, aborting threads");
+            PIKA_LOG(err, "~condition_variable: queue is not empty, aborting threads");
 
             pika::no_mutex no_mtx;
             std::unique_lock<pika::no_mutex> lock(no_mtx);
@@ -56,7 +56,7 @@ namespace pika::detail {
 
     // Return false if no more threads are waiting (returns true if queue
     // is non-empty).
-    bool condition_variable::notify_one(std::unique_lock<mutex_type> lock,
+    bool condition_variable::notify_one([[maybe_unused]] std::unique_lock<mutex_type> lock,
         execution::thread_priority /* priority */, error_code& ec)
     {
         PIKA_ASSERT(lock.owns_lock());
@@ -79,10 +79,7 @@ namespace pika::detail {
             }
 
             bool not_empty = !queue_.empty();
-            lock.unlock();
-
             ctx.resume();
-
             return not_empty;
         }
 
@@ -91,7 +88,7 @@ namespace pika::detail {
         return false;
     }
 
-    void condition_variable::notify_all(std::unique_lock<mutex_type> lock,
+    void condition_variable::notify_all([[maybe_unused]] std::unique_lock<mutex_type> lock,
         execution::thread_priority /* priority */, error_code& ec)
     {
         PIKA_ASSERT(lock.owns_lock());
@@ -110,10 +107,6 @@ namespace pika::detail {
             auto ctx = qe.ctx_;
             qe.ctx_.reset();
             queue.pop_front();
-
-            // Resume without holding lock (since resuming may yield, waiting for thread to be
-            // inactive)
-            pika::detail::unlock_guard<std::unique_lock<mutex_type>> ul(lock);
             ctx.resume();
         }
 
@@ -127,7 +120,7 @@ namespace pika::detail {
         abort_all<mutex_type>(PIKA_MOVE(lock));
     }
 
-    threads::detail::thread_restart_state condition_variable::wait(
+    pika::threads::detail::thread_restart_state condition_variable::wait(
         std::unique_lock<mutex_type>& lock, char const* /* description */, error_code& /* ec */)
     {
         PIKA_ASSERT(lock.owns_lock());
@@ -144,11 +137,11 @@ namespace pika::detail {
             this_ctx.suspend();
         }
 
-        return f.ctx_ ? threads::detail::thread_restart_state::timeout :
-                        threads::detail::thread_restart_state::signaled;
+        return f.ctx_ ? pika::threads::detail::thread_restart_state::timeout :
+                        pika::threads::detail::thread_restart_state::signaled;
     }
 
-    threads::detail::thread_restart_state condition_variable::wait_until(
+    pika::threads::detail::thread_restart_state condition_variable::wait_until(
         std::unique_lock<mutex_type>& lock, pika::chrono::steady_time_point const& abs_time,
         char const* /* description */, error_code& /* ec */)
     {
@@ -166,8 +159,8 @@ namespace pika::detail {
             this_ctx.sleep_until(abs_time.value());
         }
 
-        return f.ctx_ ? threads::detail::thread_restart_state::timeout :
-                        threads::detail::thread_restart_state::signaled;
+        return f.ctx_ ? pika::threads::detail::thread_restart_state::timeout :
+                        pika::threads::detail::thread_restart_state::signaled;
     }
 
     template <typename Mutex>
@@ -193,12 +186,11 @@ namespace pika::detail {
 
                 if (PIKA_UNLIKELY(!ctx))
                 {
-                    LERR_(fatal).format(
-                        "condition_variable::abort_all: null thread id encountered");
+                    PIKA_LOG(err, "condition_variable::abort_all: null thread id encountered");
                     continue;
                 }
 
-                LERR_(fatal).format("condition_variable::abort_all: pending thread: {}", ctx);
+                PIKA_LOG(err, "condition_variable::abort_all: pending thread: {}", ctx);
 
                 // unlock while notifying thread as this can suspend
                 ::pika::detail::unlock_guard<std::unique_lock<Mutex>> unlock(lock);
