@@ -24,7 +24,7 @@ namespace pika::util {
         // Json output for performance reports
         class json_perf_times
         {
-            using key_t = std::tuple<std::string, std::string>;
+            using key_t = std::tuple<std::string>;
             using value_t = std::vector<double>;
             using map_t = std::map<key_t, value_t>;
 
@@ -40,7 +40,6 @@ namespace pika::util {
                     if (outputs) strm << ",";
                     strm << "\n    {\n";
                     strm << "      \"name\" : \"" << std::get<0>(item.first) << "\",\n";
-                    strm << "      \"executor\" : \"" << std::get<1>(item.first) << "\",\n";
                     strm << "      \"series\" : [";
                     int series = 0;
                     for (auto val : item.second)
@@ -60,20 +59,17 @@ namespace pika::util {
             }
 
         public:
-            void add(std::string const& name, std::string const& executor, double time)
-            {
-                m_map[key_t(name, executor)].push_back(time);
-            }
+            void add(std::string const& name, double time) { m_map[key_t(name)].push_back(time); }
         };
 
         json_perf_times& times();
 
         // Add time to the map for performance report
-        void add_time(std::string const& test_name, std::string const& executor, double time);
+        void add_time(std::string const& test_name, double time);
     }    // namespace detail
 
-    PIKA_EXPORT void perftests_report(std::string const& name, std::string const& exec,
-        const std::size_t steps, detail::function<void(void)>&& test);
+    PIKA_EXPORT void perftests_report(
+        std::string const& name, const std::size_t steps, detail::function<void(void)>&& test);
 
     PIKA_EXPORT void perftests_print_times();
 
