@@ -9,7 +9,7 @@
 // openmp_parallel_region.
 
 #include <pika/chrono.hpp>
-#include <pika/future.hpp>
+#include <pika/execution.hpp>
 #include <pika/init.hpp>
 #include <pika/program_options.hpp>
 #include <pika/testing/performance.hpp>
@@ -19,6 +19,8 @@
 #include <cstdint>
 #include <iostream>
 
+namespace ex = pika::execution::experimental;
+
 int main(int argc, char** argv)
 {
     pika::program_options::options_description desc_commandline;
@@ -42,7 +44,9 @@ int main(int argc, char** argv)
 
     std::uint64_t threads = pika::resource::get_num_threads("default");
 
-    std::cout << "threads, resume [s], apply [s], suspend [s]" << std::endl;
+    auto sched = ex::thread_pool_scheduler{};
+
+    std::cout << "threads, resume [s], execute [s], suspend [s]" << std::endl;
 
     double suspend_time = 0;
     double resume_time = 0;
@@ -58,16 +62,16 @@ int main(int argc, char** argv)
 
         for (std::size_t thread = 0; thread < threads; ++thread)
         {
-            pika::apply([]() {});
+            ex::execute(sched, [] {});
         }
 
-        auto t_apply = timer.elapsed();
+        auto t_execute = timer.elapsed();
 
         pika::suspend();
         auto t_suspend = timer.elapsed();
         suspend_time += t_suspend;
 
-        std::cout << threads << ", " << t_resume << ", " << t_apply << ", " << t_suspend
+        std::cout << threads << ", " << t_resume << ", " << t_execute << ", " << t_suspend
                   << std::endl;
     }
 
@@ -75,6 +79,6 @@ int main(int argc, char** argv)
     pika::util::print_cdash_timing("SuspendTime", suspend_time);
 
     pika::resume();
-    pika::apply([]() { pika::finalize(); });
+    pika::finalize();
     pika::stop();
 }
